Documentation
¶
Overview ¶
Package output writes extracted browser data to files.
Usage:
w, _ := output.NewWriter(dir, "csv") w.Add(browserName, profileName, data) w.Write()
Supported formats: csv, json, cookie-editor.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Writer ¶
type Writer struct {
// contains filtered or unexported fields
}
Writer collects browser data and writes it to files. It is the only exported type in this package.
Click to show internal directories.
Click to hide internal directories.